@@ -135,11 +135,24 @@ bool CassieSearch::isequal(char a, char b) {
 		return true;
 	}
 	if(this->ambiguity && this->mode!=2) {
-		return Ambiguous::isequal(a,b);
+		if(Ambiguous::isequal(a,b)) {
+			return true;
+		}
 	}
-	else {
-		return a==b;
+	if(this->morphisms.size() != 0){
+			string s; s.push_back(b);
+			map<string,string>::iterator it=this->morphisms.find(string(s));
+			if ( it != this->morphisms.end() ) {
+				//Try morphisms
+				char*  morphValues = strdup(it->second.c_str());
+				for(char* it = morphValues; *it; ++it) {
+					if(*it == a) {
+						return true;
+					}
+				}
+			}
 	}
+	return false;
 }
 
 void CassieSearch::getMatchesFromNode(tree<TreeNode>::iterator sib, const int nbSubsts, const int nbIn, const int nbDel) {
